translate.storage.ini.DialectInno

Package translate :: Package storage :: Module ini :: Class DialectInno |
[hide private]
[frames] | no frames]

# Class DialectInno

source code

Instance Methods | [hide private]
unescape(self, text) | source code
escape(self, text) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### unescape(self, text) | source code
Overrides: DialectDefault.unescape

### escape(self, text) | source code
Overrides: DialectDefault.escape